==> py-subversion-1.1.3p0.tgz: lib/python2.3/site-packages/libsvn/delta.py <==
# This file was created automatically by SWIG.
# Don't modify this file, modify the SWIG interface instead.
# This file is compatible with both classic and new-style classes.

import _delta

def _swig_setattr(self,class_type,name,value):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    self.__dict__[name] = value

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types



svn_swig_py_make_editor = _delta.svn_swig_py_make_editor

svn_delta_version = _delta.svn_delta_version
svn_txdelta_source = _delta.svn_txdelta_source
svn_txdelta_target = _delta.svn_txdelta_target
svn_txdelta_new = _delta.svn_txdelta_new
class svn_txdelta_op_t(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_txdelta_op_t, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, svn_txdelta_op_t, name)
    def __repr__(self):
        return "<C svn_txdelta_op_t instance at %s>" % (self.this,)
    __swig_setmethods__["action_code"] = _delta.svn_txdelta_op_t_action_code_set
    __swig_getmethods__["action_code"] = _delta.svn_txdelta_op_t_action_code_get
    if _newclass:action_code = property(_delta.svn_txdelta_op_t_action_code_get, _delta.svn_txdelta_op_t_action_code_set)
    __swig_setmethods__["offset"] = _delta.svn_txdelta_op_t_offset_set
    __swig_getmethods__["offset"] = _delta.svn_txdelta_op_t_offset_get
    if _newclass:offset = property(_delta.svn_txdelta_op_t_offset_get, _delta.svn_txdelta_op_t_offset_set)
    __swig_setmethods__["length"] = _delta.svn_txdelta_op_t_length_set
    __swig_getmethods__["length"] = _delta.svn_txdelta_op_t_length_get
    if _newclass:length = property(_delta.svn_txdelta_op_t_length_get, _delta.svn_txdelta_op_t_length_set)
    def __init__(self, *args):
        _swig_setattr(self, svn_txdelta_op_t, 'this', _delta.new_svn_txdelta_op_t(*args))
        _swig_setattr(self, svn_txdelta_op_t, 'thisown', 1)
    def __del__(self, destroy=_delta.delete_svn_txdelta_op_t):
        try:
            if self.thisown: destroy(self)
        except: pass

class svn_txdelta_op_tPtr(svn_txdelta_op_t):
    def __init__(self, this):
        _swig_setattr(self, svn_txdelta_op_t, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, svn_txdelta_op_t, 'thisown', 0)
        _swig_setattr(self, svn_txdelta_op_t,self.__class__,svn_txdelta_op_t)
_delta.svn_txdelta_op_t_swigregister(svn_txdelta_op_tPtr)

class svn_txdelta_window_t(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_txdelta_window_t, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, svn_txdelta_window_t, name)
    def __repr__(self):
        return "<C svn_txdelta_window_t instance at %s>" % (self.this,)
    __swig_setmethods__["sview_offset"] = _delta.svn_txdelta_window_t_sview_offset_set
    __swig_getmethods__["sview_offset"] = _delta.svn_txdelta_window_t_sview_offset_get
    if _newclass:sview_offset = property(_delta.svn_txdelta_window_t_sview_offset_get, _delta.svn_txdelta_window_t_sview_offset_set)
    __swig_setmethods__["sview_len"] = _delta.svn_txdelta_window_t_sview_len_set
    __swig_getmethods__["sview_len"] = _delta.svn_txdelta_window_t_sview_len_get
    if _newclass:sview_len = property(_delta.svn_txdelta_window_t_sview_len_get, _delta.svn_txdelta_window_t_sview_len_set)
    __swig_setmethods__["tview_len"] = _delta.svn_txdelta_window_t_tview_len_set
    __swig_getmethods__["tview_len"] = _delta.svn_txdelta_window_t_tview_len_get
    if _newclass:tview_len = property(_delta.svn_txdelta_window_t_tview_len_get, _delta.svn_txdelta_window_t_tview_len_set)
    __swig_setmethods__["num_ops"] = _delta.svn_txdelta_window_t_num_ops_set
    __swig_getmethods__["num_ops"] = _delta.svn_txdelta_window_t_num_ops_get
    if _newclass:num_ops = property(_delta.svn_txdelta_window_t_num_ops_get, _delta.svn_txdelta_window_t_num_ops_set)
    __swig_setmethods__["src_ops"] = _delta.svn_txdelta_window_t_src_ops_set
    __swig_getmethods__["src_ops"] = _delta.svn_txdelta_window_t_src_ops_get
    if _newclass:src_ops = property(_delta.svn_txdelta_window_t_src_ops_get, _delta.svn_txdelta_window_t_src_ops_set)
    __swig_setmethods__["ops"] = _delta.svn_txdelta_window_t_ops_set
    __swig_getmethods__["ops"] = _delta.svn_txdelta_window_t_ops_get
    if _newclass:ops = property(_delta.svn_txdelta_window_t_ops_get, _delta.svn_txdelta_window_t_ops_set)
    __swig_getmethods__["new_data"] = _delta.svn_txdelta_window_t_new_data_get
    if _newclass:new_data = property(_delta.svn_txdelta_window_t_new_data_get)
    def __init__(self, *args):
        _swig_setattr(self, svn_txdelta_window_t, 'this', _delta.new_svn_txdelta_window_t(*args))
        _swig_setattr(self, svn_txdelta_window_t, 'thisown', 1)
    def __del__(self, destroy=_delta.delete_svn_txdelta_window_t):
        try:
            if self.thisown: destroy(self)
        except: pass

class svn_txdelta_window_tPtr(svn_txdelta_window_t):
    def __init__(self, this):
        _swig_setattr(self, svn_txdelta_window_t, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, svn_txdelta_window_t, 'thisown', 0)
        _swig_setattr(self, svn_txdelta_window_t,self.__class__,svn_txdelta_window_t)
_delta.svn_txdelta_window_t_swigregister(svn_txdelta_window_tPtr)


svn_txdelta_next_window = _delta.svn_txdelta_next_window

svn_txdelta_md5_digest = _delta.svn_txdelta_md5_digest

svn_txdelta = _delta.svn_txdelta

svn_txdelta_target_push = _delta.svn_txdelta_target_push

svn_txdelta_send_string = _delta.svn_txdelta_send_string

svn_txdelta_send_stream = _delta.svn_txdelta_send_stream

svn_txdelta_send_txstream = _delta.svn_txdelta_send_txstream

svn_txdelta_apply = _delta.svn_txdelta_apply

svn_txdelta_to_svndiff = _delta.svn_txdelta_to_svndiff

svn_txdelta_parse_svndiff = _delta.svn_txdelta_parse_svndiff

svn_txdelta_read_svndiff_window = _delta.svn_txdelta_read_svndiff_window

svn_txdelta_skip_svndiff_window = _delta.svn_txdelta_skip_svndiff_window
class svn_delta_editor_t(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_delta_editor_t, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, svn_delta_editor_t, name)
    def __repr__(self):
        return "<C svn_delta_editor_t instance at %s>" % (self.this,)
    __swig_setmethods__["set_target_revision"] = _delta.svn_delta_editor_t_set_target_revision_set
    __swig_getmethods__["set_target_revision"] = _delta.svn_delta_editor_t_set_target_revision_get
    if _newclass:set_target_revision = property(_delta.svn_delta_editor_t_set_target_revision_get, _delta.svn_delta_editor_t_set_target_revision_set)
    __swig_setmethods__["open_root"] = _delta.svn_delta_editor_t_open_root_set
    __swig_getmethods__["open_root"] = _delta.svn_delta_editor_t_open_root_get
    if _newclass:open_root = property(_delta.svn_delta_editor_t_open_root_get, _delta.svn_delta_editor_t_open_root_set)
    __swig_setmethods__["delete_entry"] = _delta.svn_delta_editor_t_delete_entry_set
    __swig_getmethods__["delete_entry"] = _delta.svn_delta_editor_t_delete_entry_get
    if _newclass:delete_entry = property(_delta.svn_delta_editor_t_delete_entry_get, _delta.svn_delta_editor_t_delete_entry_set)
    __swig_setmethods__["add_directory"] = _delta.svn_delta_editor_t_add_directory_set
    __swig_getmethods__["add_directory"] = _delta.svn_delta_editor_t_add_directory_get
    if _newclass:add_directory = property(_delta.svn_delta_editor_t_add_directory_get, _delta.svn_delta_editor_t_add_directory_set)
    __swig_setmethods__["open_directory"] = _delta.svn_delta_editor_t_open_directory_set
    __swig_getmethods__["open_directory"] = _delta.svn_delta_editor_t_open_directory_get
    if _newclass:open_directory = property(_delta.svn_delta_editor_t_open_directory_get, _delta.svn_delta_editor_t_open_directory_set)
    __swig_setmethods__["change_dir_prop"] = _delta.svn_delta_editor_t_change_dir_prop_set
    __swig_getmethods__["change_dir_prop"] = _delta.svn_delta_editor_t_change_dir_prop_get
    if _newclass:change_dir_prop = property(_delta.svn_delta_editor_t_change_dir_prop_get, _delta.svn_delta_editor_t_change_dir_prop_set)
    __swig_setmethods__["close_directory"] = _delta.svn_delta_editor_t_close_directory_set
    __swig_getmethods__["close_directory"] = _delta.svn_delta_editor_t_close_directory_get
    if _newclass:close_directory = property(_delta.svn_delta_editor_t_close_directory_get, _delta.svn_delta_editor_t_close_directory_set)
    __swig_setmethods__["absent_directory"] = _delta.svn_delta_editor_t_absent_directory_set
    __swig_getmethods__["absent_directory"] = _delta.svn_delta_editor_t_absent_directory_get
    if _newclass:absent_directory = property(_delta.svn_delta_editor_t_absent_directory_get, _delta.svn_delta_editor_t_absent_directory_set)
    __swig_setmethods__["add_file"] = _delta.svn_delta_editor_t_add_file_set
    __swig_getmethods__["add_file"] = _delta.svn_delta_editor_t_add_file_get
    if _newclass:add_file = property(_delta.svn_delta_editor_t_add_file_get, _delta.svn_delta_editor_t_add_file_set)
    __swig_setmethods__["open_file"] = _delta.svn_delta_editor_t_open_file_set
    __swig_getmethods__["open_file"] = _delta.svn_delta_editor_t_open_file_get
    if _newclass:open_file = property(_delta.svn_delta_editor_t_open_file_get, _delta.svn_delta_editor_t_open_file_set)
    __swig_setmethods__["apply_textdelta"] = _delta.svn_delta_editor_t_apply_textdelta_set
    __swig_getmethods__["apply_textdelta"] = _delta.svn_delta_editor_t_apply_textdelta_get
    if _newclass:apply_textdelta = property(_delta.svn_delta_editor_t_apply_textdelta_get, _delta.svn_delta_editor_t_apply_textdelta_set)
    __swig_setmethods__["change_file_prop"] = _delta.svn_delta_editor_t_change_file_prop_set
    __swig_getmethods__["change_file_prop"] = _delta.svn_delta_editor_t_change_file_prop_get
    if _newclass:change_file_prop = property(_delta.svn_delta_editor_t_change_file_prop_get, _delta.svn_delta_editor_t_change_file_prop_set)
    __swig_setmethods__["close_file"] = _delta.svn_delta_editor_t_close_file_set
    __swig_getmethods__["close_file"] = _delta.svn_delta_editor_t_close_file_get
    if _newclass:close_file = property(_delta.svn_delta_editor_t_close_file_get, _delta.svn_delta_editor_t_close_file_set)
    __swig_setmethods__["absent_file"] = _delta.svn_delta_editor_t_absent_file_set
    __swig_getmethods__["absent_file"] = _delta.svn_delta_editor_t_absent_file_get
    if _newclass:absent_file = property(_delta.svn_delta_editor_t_absent_file_get, _delta.svn_delta_editor_t_absent_file_set)
    __swig_setmethods__["close_edit"] = _delta.svn_delta_editor_t_close_edit_set
    __swig_getmethods__["close_edit"] = _delta.svn_delta_editor_t_close_edit_get
    if _newclass:close_edit = property(_delta.svn_delta_editor_t_close_edit_get, _delta.svn_delta_editor_t_close_edit_set)
    __swig_setmethods__["abort_edit"] = _delta.svn_delta_editor_t_abort_edit_set
    __swig_getmethods__["abort_edit"] = _delta.svn_delta_editor_t_abort_edit_get
    if _newclass:abort_edit = property(_delta.svn_delta_editor_t_abort_edit_get, _delta.svn_delta_editor_t_abort_edit_set)
    def __init__(self, *args):
        _swig_setattr(self, svn_delta_editor_t, 'this', _delta.new_svn_delta_editor_t(*args))
        _swig_setattr(self, svn_delta_editor_t, 'thisown', 1)
    def __del__(self, destroy=_delta.delete_svn_delta_editor_t):
        try:
            if self.thisown: destroy(self)
        except: pass

class svn_delta_editor_tPtr(svn_delta_editor_t):
    def __init__(self, this):
        _swig_setattr(self, svn_delta_editor_t, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, svn_delta_editor_t, 'thisown', 0)
        _swig_setattr(self, svn_delta_editor_t,self.__class__,svn_delta_editor_t)
_delta.svn_delta_editor_t_swigregister(svn_delta_editor_tPtr)


svn_delta_default_editor = _delta.svn_delta_default_editor

svn_delta_noop_window_handler = _delta.svn_delta_noop_window_handler

svn_delta_get_cancellation_editor = _delta.svn_delta_get_cancellation_editor

svn_delta_path_driver = _delta.svn_delta_path_driver

==> py-subversion-1.2.1.tgz: lib/python2.3/site-packages/libsvn/delta.py <==
# This file was created automatically by SWIG.
# Don't modify this file, modify the SWIG interface instead.
# This file is compatible with both classic and new-style classes.

import _delta

def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name) or (name == "thisown"):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types



svn_swig_py_make_editor = _delta.svn_swig_py_make_editor

svn_delta_version = _delta.svn_delta_version
svn_txdelta_source = _delta.svn_txdelta_source
svn_txdelta_target = _delta.svn_txdelta_target
svn_txdelta_new = _delta.svn_txdelta_new
class svn_txdelta_op_t(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_txdelta_op_t, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, svn_txdelta_op_t, name)
    def __repr__(self):
        return "<%s.%s; proxy of C svn_txdelta_op_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    __swig_setmethods__["action_code"] = _delta.svn_txdelta_op_t_action_code_set
    __swig_getmethods__["action_code"] = _delta.svn_txdelta_op_t_action_code_get
    if _newclass:action_code = property(_delta.svn_txdelta_op_t_action_code_get, _delta.svn_txdelta_op_t_action_code_set)
    __swig_setmethods__["offset"] = _delta.svn_txdelta_op_t_offset_set
    __swig_getmethods__["offset"] = _delta.svn_txdelta_op_t_offset_get
    if _newclass:offset = property(_delta.svn_txdelta_op_t_offset_get, _delta.svn_txdelta_op_t_offset_set)
    __swig_setmethods__["length"] = _delta.svn_txdelta_op_t_length_set
    __swig_getmethods__["length"] = _delta.svn_txdelta_op_t_length_get
    if _newclass:length = property(_delta.svn_txdelta_op_t_length_get, _delta.svn_txdelta_op_t_length_set)
    def __init__(self, *args):
        _swig_setattr(self, svn_txdelta_op_t, 'this', _delta.new_svn_txdelta_op_t(*args))
        _swig_setattr(self, svn_txdelta_op_t, 'thisown', 1)
    def __del__(self, destroy=_delta.delete_svn_txdelta_op_t):
        try:
            if self.thisown: destroy(self)
        except: pass


class svn_txdelta_op_tPtr(svn_txdelta_op_t):
    def __init__(self, this):
        _swig_setattr(self, svn_txdelta_op_t, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, svn_txdelta_op_t, 'thisown', 0)
        _swig_setattr(self, svn_txdelta_op_t,self.__class__,svn_txdelta_op_t)
_delta.svn_txdelta_op_t_swigregister(svn_txdelta_op_tPtr)

class svn_txdelta_window_t(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_txdelta_window_t, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, svn_txdelta_window_t, name)
    def __repr__(self):
        return "<%s.%s; proxy of C svn_txdelta_window_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    __swig_setmethods__["sview_offset"] = _delta.svn_txdelta_window_t_sview_offset_set
    __swig_getmethods__["sview_offset"] = _delta.svn_txdelta_window_t_sview_offset_get
    if _newclass:sview_offset = property(_delta.svn_txdelta_window_t_sview_offset_get, _delta.svn_txdelta_window_t_sview_offset_set)
    __swig_setmethods__["sview_len"] = _delta.svn_txdelta_window_t_sview_len_set
    __swig_getmethods__["sview_len"] = _delta.svn_txdelta_window_t_sview_len_get
    if _newclass:sview_len = property(_delta.svn_txdelta_window_t_sview_len_get, _delta.svn_txdelta_window_t_sview_len_set)
    __swig_setmethods__["tview_len"] = _delta.svn_txdelta_window_t_tview_len_set
    __swig_getmethods__["tview_len"] = _delta.svn_txdelta_window_t_tview_len_get
    if _newclass:tview_len = property(_delta.svn_txdelta_window_t_tview_len_get, _delta.svn_txdelta_window_t_tview_len_set)
    __swig_setmethods__["num_ops"] = _delta.svn_txdelta_window_t_num_ops_set
    __swig_getmethods__["num_ops"] = _delta.svn_txdelta_window_t_num_ops_get
    if _newclass:num_ops = property(_delta.svn_txdelta_window_t_num_ops_get, _delta.svn_txdelta_window_t_num_ops_set)
    __swig_setmethods__["src_ops"] = _delta.svn_txdelta_window_t_src_ops_set
    __swig_getmethods__["src_ops"] = _delta.svn_txdelta_window_t_src_ops_get
    if _newclass:src_ops = property(_delta.svn_txdelta_window_t_src_ops_get, _delta.svn_txdelta_window_t_src_ops_set)
    __swig_setmethods__["ops"] = _delta.svn_txdelta_window_t_ops_set
    __swig_getmethods__["ops"] = _delta.svn_txdelta_window_t_ops_get
    if _newclass:ops = property(_delta.svn_txdelta_window_t_ops_get, _delta.svn_txdelta_window_t_ops_set)
    __swig_getmethods__["new_data"] = _delta.svn_txdelta_window_t_new_data_get
    if _newclass:new_data = property(_delta.svn_txdelta_window_t_new_data_get)
    def __init__(self, *args):
        _swig_setattr(self, svn_txdelta_window_t, 'this', _delta.new_svn_txdelta_window_t(*args))
        _swig_setattr(self, svn_txdelta_window_t, 'thisown', 1)
    def __del__(self, destroy=_delta.delete_svn_txdelta_window_t):
        try:
            if self.thisown: destroy(self)
        except: pass


class svn_txdelta_window_tPtr(svn_txdelta_window_t):
    def __init__(self, this):
        _swig_setattr(self, svn_txdelta_window_t, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, svn_txdelta_window_t, 'thisown', 0)
        _swig_setattr(self, svn_txdelta_window_t,self.__class__,svn_txdelta_window_t)
_delta.svn_txdelta_window_t_swigregister(svn_txdelta_window_tPtr)


svn_txdelta_next_window = _delta.svn_txdelta_next_window

svn_txdelta_md5_digest = _delta.svn_txdelta_md5_digest

svn_txdelta = _delta.svn_txdelta

svn_txdelta_target_push = _delta.svn_txdelta_target_push

svn_txdelta_send_string = _delta.svn_txdelta_send_string

svn_txdelta_send_stream = _delta.svn_txdelta_send_stream

svn_txdelta_send_txstream = _delta.svn_txdelta_send_txstream

svn_txdelta_apply = _delta.svn_txdelta_apply

svn_txdelta_to_svndiff = _delta.svn_txdelta_to_svndiff

svn_txdelta_parse_svndiff = _delta.svn_txdelta_parse_svndiff

svn_txdelta_read_svndiff_window = _delta.svn_txdelta_read_svndiff_window

svn_txdelta_skip_svndiff_window = _delta.svn_txdelta_skip_svndiff_window
class svn_delta_editor_t(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_delta_editor_t, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, svn_delta_editor_t, name)
    def __repr__(self):
        return "<%s.%s; proxy of C svn_delta_editor_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    __swig_setmethods__["set_target_revision"] = _delta.svn_delta_editor_t_set_target_revision_set
    __swig_getmethods__["set_target_revision"] = _delta.svn_delta_editor_t_set_target_revision_get
    if _newclass:set_target_revision = property(_delta.svn_delta_editor_t_set_target_revision_get, _delta.svn_delta_editor_t_set_target_revision_set)
    __swig_setmethods__["open_root"] = _delta.svn_delta_editor_t_open_root_set
    __swig_getmethods__["open_root"] = _delta.svn_delta_editor_t_open_root_get
    if _newclass:open_root = property(_delta.svn_delta_editor_t_open_root_get, _delta.svn_delta_editor_t_open_root_set)
    __swig_setmethods__["delete_entry"] = _delta.svn_delta_editor_t_delete_entry_set
    __swig_getmethods__["delete_entry"] = _delta.svn_delta_editor_t_delete_entry_get
    if _newclass:delete_entry = property(_delta.svn_delta_editor_t_delete_entry_get, _delta.svn_delta_editor_t_delete_entry_set)
    __swig_setmethods__["add_directory"] = _delta.svn_delta_editor_t_add_directory_set
    __swig_getmethods__["add_directory"] = _delta.svn_delta_editor_t_add_directory_get
    if _newclass:add_directory = property(_delta.svn_delta_editor_t_add_directory_get, _delta.svn_delta_editor_t_add_directory_set)
    __swig_setmethods__["open_directory"] = _delta.svn_delta_editor_t_open_directory_set
    __swig_getmethods__["open_directory"] = _delta.svn_delta_editor_t_open_directory_get
    if _newclass:open_directory = property(_delta.svn_delta_editor_t_open_directory_get, _delta.svn_delta_editor_t_open_directory_set)
    __swig_setmethods__["change_dir_prop"] = _delta.svn_delta_editor_t_change_dir_prop_set
    __swig_getmethods__["change_dir_prop"] = _delta.svn_delta_editor_t_change_dir_prop_get
    if _newclass:change_dir_prop = property(_delta.svn_delta_editor_t_change_dir_prop_get, _delta.svn_delta_editor_t_change_dir_prop_set)
    __swig_setmethods__["close_directory"] = _delta.svn_delta_editor_t_close_directory_set
    __swig_getmethods__["close_directory"] = _delta.svn_delta_editor_t_close_directory_get
    if _newclass:close_directory = property(_delta.svn_delta_editor_t_close_directory_get, _delta.svn_delta_editor_t_close_directory_set)
    __swig_setmethods__["absent_directory"] = _delta.svn_delta_editor_t_absent_directory_set
    __swig_getmethods__["absent_directory"] = _delta.svn_delta_editor_t_absent_directory_get
    if _newclass:absent_directory = property(_delta.svn_delta_editor_t_absent_directory_get, _delta.svn_delta_editor_t_absent_directory_set)
    __swig_setmethods__["add_file"] = _delta.svn_delta_editor_t_add_file_set
    __swig_getmethods__["add_file"] = _delta.svn_delta_editor_t_add_file_get
    if _newclass:add_file = property(_delta.svn_delta_editor_t_add_file_get, _delta.svn_delta_editor_t_add_file_set)
    __swig_setmethods__["open_file"] = _delta.svn_delta_editor_t_open_file_set
    __swig_getmethods__["open_file"] = _delta.svn_delta_editor_t_open_file_get
    if _newclass:open_file = property(_delta.svn_delta_editor_t_open_file_get, _delta.svn_delta_editor_t_open_file_set)
    __swig_setmethods__["apply_textdelta"] = _delta.svn_delta_editor_t_apply_textdelta_set
    __swig_getmethods__["apply_textdelta"] = _delta.svn_delta_editor_t_apply_textdelta_get
    if _newclass:apply_textdelta = property(_delta.svn_delta_editor_t_apply_textdelta_get, _delta.svn_delta_editor_t_apply_textdelta_set)
    __swig_setmethods__["change_file_prop"] = _delta.svn_delta_editor_t_change_file_prop_set
    __swig_getmethods__["change_file_prop"] = _delta.svn_delta_editor_t_change_file_prop_get
    if _newclass:change_file_prop = property(_delta.svn_delta_editor_t_change_file_prop_get, _delta.svn_delta_editor_t_change_file_prop_set)
    __swig_setmethods__["close_file"] = _delta.svn_delta_editor_t_close_file_set
    __swig_getmethods__["close_file"] = _delta.svn_delta_editor_t_close_file_get
    if _newclass:close_file = property(_delta.svn_delta_editor_t_close_file_get, _delta.svn_delta_editor_t_close_file_set)
    __swig_setmethods__["absent_file"] = _delta.svn_delta_editor_t_absent_file_set
    __swig_getmethods__["absent_file"] = _delta.svn_delta_editor_t_absent_file_get
    if _newclass:absent_file = property(_delta.svn_delta_editor_t_absent_file_get, _delta.svn_delta_editor_t_absent_file_set)
    __swig_setmethods__["close_edit"] = _delta.svn_delta_editor_t_close_edit_set
    __swig_getmethods__["close_edit"] = _delta.svn_delta_editor_t_close_edit_get
    if _newclass:close_edit = property(_delta.svn_delta_editor_t_close_edit_get, _delta.svn_delta_editor_t_close_edit_set)
    __swig_setmethods__["abort_edit"] = _delta.svn_delta_editor_t_abort_edit_set
    __swig_getmethods__["abort_edit"] = _delta.svn_delta_editor_t_abort_edit_get
    if _newclass:abort_edit = property(_delta.svn_delta_editor_t_abort_edit_get, _delta.svn_delta_editor_t_abort_edit_set)
    def __init__(self, *args):
        _swig_setattr(self, svn_delta_editor_t, 'this', _delta.new_svn_delta_editor_t(*args))
        _swig_setattr(self, svn_delta_editor_t, 'thisown', 1)
    def __del__(self, destroy=_delta.delete_svn_delta_editor_t):
        try:
            if self.thisown: destroy(self)
        except: pass


class svn_delta_editor_tPtr(svn_delta_editor_t):
    def __init__(self, this):
        _swig_setattr(self, svn_delta_editor_t, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, svn_delta_editor_t, 'thisown', 0)
        _swig_setattr(self, svn_delta_editor_t,self.__class__,svn_delta_editor_t)
_delta.svn_delta_editor_t_swigregister(svn_delta_editor_tPtr)


svn_delta_default_editor = _delta.svn_delta_default_editor

svn_delta_noop_window_handler = _delta.svn_delta_noop_window_handler

svn_delta_get_cancellation_editor = _delta.svn_delta_get_cancellation_editor

svn_delta_path_driver = _delta.svn_delta_path_driver
